***************************
Instructions:

Download the 2023 HAI Event MRAT data from REDCap by using the 'Data Exports, Reports, and Stats' 
option on the left-hand menu. Be sure to select "raw" data, and export as a .csv file using 
variable names, not labels. Save the file in a secure location and enter the filepath below.

For step by step instructions on exporting data, follow steps 1-5 of the How-To document located
at the link below. You DO NOT need to deidentify your data for this code and report. Please ignore
that step in the guidance document.
	https://www.cdc.gov/nhsn/pdfs/validation/2023/export-data-from-REDCap.pdf

Enter the HAI you are validating, Redcap MRAT data filepath, and the facility's name and 
orgID below, where prompted. Do not use quotes and do not delete the semicolons.

Once these 4 items are entered, no other edits are needed to run the program. Just click "Run".

There is one dataset titled "[HAI]NeedsReview". If there are any observations in this dataset,
please review the case classification for that record and make any needed updates within 
Redcap. You will need to re-export the data once updates are made.

*****************************;

*Enter the specific HAI of interest: CLABSI, CAUTI, HYST, COLO, CDI, or MRSA.;
%let HAI=CLABSI;

*Enter the filepath, including the file name and extension;
%let path = C:\folder path\2023\Filename of REDCap Data.csv;

*Enter the facility's name, exactly as you want it written in the report;
%let facname = CDC Medical Center;

*Enter facility's orgID;
%let orgid= 1234;

options mprint mlogic symbolgen;

%macro Summary;
%if &HAI=CLABSI %then %do;
proc import datafile="&path" 
out=clabsi (where=(orgid_clabsi_2023 =&orgid))
dbms=csv replace;
guessingrows=1000;
run;

proc format;
value casedet
1="Correctly Reported/Correctly Not Reported"
2="Over-reported HAI"
3="Under-reported HAI";

value $ oc_clabsi
"a"="(a) No candidate validation location (VL) CLABSI"
"b"="(b) No LCBI (specify)"
"c"="(c) POA LCBI"
"d"="(d) HAI-LCBI not CLABSI"
"e"="(e) CLABSI not VL attributable"
"f"="(f) VL CLABSI";

value mc_clabsi
1= "(I) General HAI definition misapplication"
2= "(II) CLABSI criteria misapplied"
3= "(III) Additional Reasons";

value $ mc_i_clabsi
"a" = "(Ia) Incorrect location of attribution"
"b" = "(Ib) Date of event incorrect"
"c" = "(Ic) IWP set incorrectly"
"d" = "(Id) RIT applied incorrectly"
"e" = "(Ie) Did not identify elements present in IWP"
"f" = "(If) POA/HAI applied incorrectly"
"h" = "(Ih) Other (specify)";

value $ mc_ii_clabsi
"a" = "(IIa) Central Line not in > 2 days in an inpatient location on date of event"
"b" = "(IIb) Missed CLABSI due to central line removed day of or day before the date of event"
"c" = "(IIc) Missed CLABSI due to location transfer/discharge day of or day before the date of event"
"d" = "(IId) CLABSI incorrectly identified as secondary BSI"
"e" = "(IIe) Secondary BSI incorrectly identified as a primary CLABSI"
"f" = "(IIf) Other (specify)";

value $ mc_iii_clabsi
"a" = "(IIIa) Missed case finding/failure to review positive specimen/culture"
"b" = "(IIIb) Clinical over-rule"
"c" = "(IIIc) Used outdated criteria"
"d" = "(IIId) No positive blood specimen in chart"
"e" = "(IIIe) Other (specify)";

value nolcbispec
1="Contaminant (unmatched CC)"
2="Matching CCs with no symptoms"
3="Alternative primary source of BSI";

value nolcbichap 
1= "At least one organism from the blood specimen matches an organism identified from the site-specific infection that is used as an element to meet the NHSN site-specific infection criterion AND the blood specimen is collected during the secondary BSI attribution period (infection window period + repeat infection time frame)."
2= "An organism identified in the blood specimen is an element that is used to meet the NHSN site-specific infection criterion, and therefore is collected during the site-specific infection window period";

value lcbitype
1="LCBI 1"
2="MBI - LCBI 1"
3="LCBI 2"
4="MBI - LCBI 2"
5="LCBI 3"
6="MBI - LCBI 3";

value haipoa
1="POA"
0="HAI";

value resultstat
1="True Positive"
2="False Negative"
3="False Positive"
4="True Negative" 
9="Review";

value yesno
1="Yes"
0="No";
run;

data outcome_clabsi;
set clabsi;
keep record_id orgid_clabsi_2023 orgrandomid_clabsi_2023 patientid_clabsi_2023 auditdt_clabsi_2023 reviewer_clabsi_2023 
screeningcasedet_clabsi_2023 screeningoutcome_clabsi_2023 rit: pbccolldt1_: pbcdoe1_: ;
run;

proc sort data=outcome_clabsi; by record_id; run;

data clabsi2;
set clabsi (rename= (orgid_clabsi_2023=orgid_clabsi patientid_clabsi_2023=patientid_clabsi 
rit1qualifylcbi_clabsi_2023=qualifylcbi rit1lcbitype_clabsi_2023=lcbitype 
rit1lcbihaipoa_clabsi_2023=lcbihaipoa rit1lcbiexclyn_clabsi_2023=lcbiexclcriteria 
rit1excrit_clabsi_2023___ecmovad=lcbiecmovad rit1excrit_clabsi_2023___selfinj=lcbiselfinj 
rit1excrit_clabsi_2023___ebmsbp=lcbiebmsbp rit1excrit_clabsi_2023___gbs=lcbigbs 
rit1excrit_clabsi_2023___pus=lcbipus pbccolldt1_clabsi_2023=selPBCcolldt 
pbcdoe1_clabsi_2023=selPBCEventdt rit1ocnolcbispec_clabsi_2023=ocnolcbispec 
rit1ocnolcbialtsrc_clabsi_2023=ocnolcbialtsrc rit1ocnolcbiasdt_clabsi_2023=ocnolcbialtsrcdt 
rit1ocnolcbichap_clabsi_2023=ocnolcbichap rit1mc_i_othspec_clabsi_2023=misclass_i_spec 
rit1mc_ii_othspec_clabsi_2023=misclass_ii_spec rit1mc_iii_othspec_clabsi_2023=misclass_iii_spec));
length oc casedet $100. misclass_i misclass_ii misclass_iii $500.;

if screeningoutcome_clabsi_2023 ne "" then oc=put(screeningoutcome_clabsi_2023, $oc_clabsi.);
else if rit1outcome_clabsi_2023 ne "" then oc=put(rit1outcome_clabsi_2023, $oc_clabsi.);
if screeningoutcome_clabsi_2023 ne "" then _oc=screeningoutcome_clabsi_2023;
else if rit1outcome_clabsi_2023 ne "" then _oc=rit1outcome_clabsi_2023;

if screeningcasedet_clabsi_2023 ne . then casedet=put(screeningcasedet_clabsi_2023, casedet.);
else if rit1casedet_clabsi_2023 ne . then casedet=put(rit1casedet_clabsi_2023, casedet.);
if screeningcasedet_clabsi_2023 ne . then _casedet=screeningcasedet_clabsi_2023;
else if rit1casedet_clabsi_2023 ne . then _casedet=rit1casedet_clabsi_2023;

if rit1misclassreason_clabsi_2023 ne . then misclass=put(rit1misclassreason_clabsi_2023, mc_clabsi.);
if rit1misclass_i_clabsi_2023 ne "" then misclass_i=put(rit1misclass_i_clabsi_2023, $mc_i_clabsi.);
if rit1misclass_ii_clabsi_2023 ne "" then misclass_ii=put(rit1misclass_ii_clabsi_2023, $mc_ii_clabsi.);
if rit1misclass_iii_clabsi_2023 ne "" then misclass_iii=put(rit1misclass_iii_clabsi_2023, $mc_iii_clabsi.);

format lcbitype lcbitype. selPBCEventdt selPBCcolldt mmddyy10. lcbihaipoa haipoa. 
qualifylcbi lcbiecmovad lcbiselfinj lcbiebmsbp lcbigbs lcbipus  yesno.  
ocnolcbispec nolcbispec. ocnolcbichap nolcbichap.;
run;

data clabsi4 clabsineedsreview;
set clabsi2 ;
length misclassreason outcome $500. _ocno: $300.;

if ocnolcbispec ne . then do;
_ocnolcbispec = put(ocnolcbispec, nolcbispec.); end; else _ocnolcbispec="";
if ocnolcbichap ne . then do;
_ocnolcbichap=put(ocnolcbichap, nolcbichap.); end; else _ocnolcbichap="";

if ocnolcbialtsrcdt ne . then do; 
_ocnolcbialtsrcdt = catx(": ", "Alternative Source Date", put(ocnolcbialtsrcdt, mmddyy10.)); end;
else _ocnolcbialtsrcdt="";

if oc ne "" then do;
Outcome=catx(": ", oc , _ocnolcbispec, ocnolcbialtsrc, _ocnolcbialtsrcdt, _ocnolcbichap); end;
else Outcome = "";

Misclassreason=catx(": ", misclass, misclass_i, misclass_i_spec, misclass_ii, misclass_ii_spec, misclass_iii, misclass_iii_spec);

*Creating tp/fp/tn/fn;
if _oc in ("e" "f") and _casedet = 1 then do;
	Validator=1; Facility=1; Resultstatus=1; end; *TP;
if _oc in ("a" "b" "c" "d") and _casedet = 1 then do;
	Validator=0; Facility=0; Resultstatus=4; end; *TN;
if _oc in ("e" "f") and _casedet = 3 then do;
	Validator=1; Facility=0; Resultstatus=2; end; *FN;
if _oc in ("a" "b" "c" "d") and _casedet = 2 then do;
	Validator=0; Facility=1; Resultstatus=3; end; *FP;
if _oc in ("e" "f") and _casedet = 2 then Resultstatus=9; *review;
if _oc in ("a" "b" "c" "d") and _casedet = 3 then Resultstatus=9; *review;
if resultstatus=9 then output clabsineedsreview;
else output clabsi4;
label orgid_clabsi="OrgID" patientid_clabsi="Patient ID"  casedet="Case Determination";
format resultstatus resultstat.;
run;

*2x2 tables;
proc sort data=clabsi4; by descending Facility descending Validator; run;
proc freq data=clabsi4 order=data;
by orgid_clabsi; 
table facility*validator/nocol nocum norow nopercent out=clabsi_freqsb;
format facility Validator yesno.;
run;

data clabsi_freqs;length fac $5.;
set clabsi_freqsb;
fac=put(facility, yesno.);
run;

proc sql; create table clabsi_peragreement as select orgid_clabsi,
sum((case when facility=1 and validator=1 then count else 0 end) + 
		(case when facility=0 and validator=0 then count else 0 end)) as numerator,
sum(count) as denom, put(round(calculated numerator/(calculated denom)*100,.1),4.1) as PerAgree
from clabsi_freqs 
group by orgid_clabsi;
quit;

data _null_;
set clabsi_peragreement;
call symput ('clabsipa', peragree);
call scan("&path", -1, pos, length,"\");
call symput("reppath", substr("&path",1,pos-2) || "\CLABSI - &facname Validation Summary Report %sysfunc(date(),mmddyyd10.).xlsx");
run; 
%put &clabsipa; 
%put &reppath;

proc sort data=clabsi_freqs; by descending Validator descending fac; run;
proc sort data=clabsi4; by patientid_clabsi selPBCEventdt; run;

*Creating report;
ods excel file = "&reppath" 
options(sheet_interval='none' embedded_titles='yes' 
sheet_name = "2x2 Table");options missing=0;
title1 color=black "&facname CLABSI Event Validation Summary";
title2;
proc report data=clabsi_freqs nowd 
style(column)=[just=left frame=box bordercolor=black ] 
style(header)=[background=lightblue color=black fontsize=9pt bordercolor=black] 
style(lines)=[just=left fontsize=7pt color=black tagattr="wrap:no" bordercolor=white];
title1 c=black h=11pt j=center "&facname CLABSI Event Validation";
column ("Facility" fac) ("Validator" (validator, count ("Total" (count=all))));
define fac / group "" order=data ;
define validator /group across order=data "" format=yesno.;
define count / missing "" ;
define all / missing "" ;
RBREAK AFTER /summarize style=[color=black];
compute after;
	fac="Total";
	line "Percent Agreement = %SYSFUNC(strip(&clabsipa))%"; endcomp;
compute before _page_ /style=[background=white color=black tagattr="wrap:no" fontsize=10pt bordercolor=white bordertopcolor=white just=left];
	line "Table 1. CLABSI Event Validation Agreement"; endcomp;
run;
title1;
*Linelist;
ods excel options(sheet_name = "CLABSI Linelist" sheet_interval="now" 
flow="header, data");
proc report data=clabsi4 nowd
style(column)=[just=left frame=box verticalalign=top]
style(header)=[background=lightblue font_size=8pt color=black  bordercolor=black cellspacing=1];
label; column orgid_clabsi patientid_clabsi outcome casedet misclassreason; 
define outcome / "Outcome";
define misclassreason / "Misclassification Reason(s)";
	 run;
ods excel close; options missing=.;
%end;

/*CAUTI*/
%else %if &HAI=CAUTI %then %do;
proc import datafile="&path" 
out=cauti (where=(orgid_cauti_2023 =&orgid))
dbms=csv replace;
guessingrows=1000;
run;

proc format;
value casedet
1="Correctly Reported/Correctly Not Reported"
2="Over-reported HAI"
3="Under-reported HAI";

value $ oc_cauti
"a"="(a) Not a candidate VL CAUTI"
"b"="(b) No UTI; symptomatic but no matching blood pathogen"
"c"="(c) POA UTI, not HAI"
"d"="(d) HAI-UTI, not CAUTI"
"e"="(e) CAUTI, not VL attributable"
"f"="(f) VL CAUTI";

value mc_cauti
1= "(I) General HAI definition misapplication"
2= "(II) CAUTI criteria misapplied"
3= "(III) Additional Reasons";

value $ mc_i_cauti
"a" = "(Ia) Incorrect location of attribution"
"b" = "(Ib) Date of event incorrect"
"c" = "(Ic) IWP set incorrectly"
"d" = "(Id) RIT applied incorrectly"
"e" = "(Ie) Did not identify elements present in IWP"
"f" = "(If) POA/HAI applied incorrectly"
"g" = "(Ig) Other (specify)";

value $ mc_ii_cauti
"a"="(IIa) Urinary catheter not in > 2 days in an inpatient location on date of event"
"b"="(IIb) Urine culture not appropriate"
"c"="(IIc) Asymptomatic CAUTI reported"
"d"="(IId) Missed CAUTI due to catheter removed day of or day before the date of event"
"e"="(IIe) Missed CAUTI due to location transfer/discharge on date of event or day before"
"f"="(IIf) ABUTI identified incorrectly"
"g"="(IIg) Other (specify)";

value $ mc_iii_cauti
"a" = "(IIIa) Missed case finding/failure to review positive culture"
"b" = "(IIIb) Clinical over-rule"
"c" = "(IIIc) Used outdated criteria"
"d" = "(IIId) No urine culture in chart"
"e" = "(IIIe) Other (specify)";

value utitype
1="SUTI 1a (CAUTI)"
2="SUTI 1b (non-CAUTI)"
3="SUTI 2"
4="ABUTI"
9="n/a";

value haipoa
1="POA"
0="HAI";

value resultstat
1="True Positive"
2="False Negative"
3="False Positive"
4="True Negative" 
9="Review";
value yesno
1="Yes"
0="No";
run;

data outcome_cauti;
set cauti;
keep record_id orgid_cauti_2023 orgrandomid_cauti_2023 patientid_cauti_2023 auditdt_cauti_2023 
reviewer_cauti_2023 screeningcasedet_cauti_2023 screeningoutcome_cauti_2023 uti: ;
run;

proc sort data=outcome_cauti; by orgid_cauti_2023 record_id patientid_cauti_2023; run;

data cauti2;
set cauti;
length outcome casedet $100. misclass: $500.;

if screeningoutcome_cauti_2023 ne "" then outcome=put(screeningoutcome_cauti_2023, $oc_cauti.);
else if uti1outcome_cauti_2023 ne "" then outcome=put(uti1outcome_cauti_2023, $oc_cauti.);

if screeningcasedet_cauti_2023 ne . then casedet=put(screeningcasedet_cauti_2023, casedet.);
else if uti1casedet_cauti_2023 ne . then casedet=put(uti1casedet_cauti_2023, casedet.);

if uti1type_cauti_2023 ne . then utitype=put(uti1type_cauti_2023, utitype.);
if uti1misclassreason_cauti_2023 ne . then misclass=put(uti1misclassreason_cauti_2023, mc_cauti.);
if uti1misclass_i_cauti_2023 ne "" then misclass_i=put(uti1misclass_i_cauti_2023, $mc_i_cauti.);
if uti1misclass_ii_cauti_2023 ne "" then misclass_ii=put(uti1misclass_ii_cauti_2023, $mc_ii_cauti.);
if uti1misclass_iii_cauti_2023 ne "" then misclass_iii=put(uti1misclass_iii_cauti_2023, $mc_iii_cauti.);

rename orgid_cauti_2023=orgid_cauti patientid_cauti_2023=patientid_cauti uti1doe_cauti_2023=utieventdt 
uti1mc_i_othspec_cauti_2023=misclass_i_spec uti1mc_ii_othspec_cauti_2023=misclass_ii_spec 
uti1mc_iii_othspec_cauti_2023=misclass_iii_spec;
run;

data cauti4 cautineedsreview;
set cauti2; length misclassreason $500.;
misclassreason=catx(": ", misclass, misclass_i, misclass_i_spec, misclass_ii, misclass_ii_spec, 
misclass_iii, misclass_iii_spec);

if misclassreason ne "" then do;
if misclass_i ne "" then  mcrep=misclass_i; 
else if misclass_ii ne "" then mcrep=misclass_ii;
else if misclass_iii ne "" then mcrep=misclass_iii;
else if mcrep = "" then mcrep="Unknown";
if index(mcrep,"Other (specify)") > 0 then mcrep = "Other";
else mcrep=scan(mcrep,-1,")"); 
end;

if screeningoutcome_cauti_2023 ne "" then _oc=screeningoutcome_cauti_2023;
	else if uti1outcome_cauti_2023 ne "" then _oc=uti1outcome_cauti_2023;
if screeningcasedet_cauti_2023 ne . then _casedet=screeningcasedet_cauti_2023;
	else if uti1casedet_cauti_2023 ne . then _casedet=uti1casedet_cauti_2023;

*Creating tp/fp/tn/fn;
if _oc in ("e" "f") and _casedet = 1 then do;
	Validator=1; Facility=1; Resultstatus=1; end; *TP;
if _oc in ("a" "b" "c" "d") and _casedet = 1 then do;
	Validator=0; Facility=0; Resultstatus=4; end; *TN;
if _oc in ("e" "f") and _casedet = 3 then do;
	Validator=1; Facility=0; Resultstatus=2; end; *FN;
if _oc in ("a" "b" "c" "d") and _casedet = 2 then do;
	Validator=0; Facility=1; Resultstatus=3; end; *FP;
if _oc in ("e" "f") and _casedet = 2 then Resultstatus=9; *review;
if _oc in ("a" "b" "c" "d") and _casedet = 3 then Resultstatus=9; *review;
if utitype = "" and _oc = "a" then utitype="n/a";

label orgid_cauti="OrgID" patientid_cauti="Patient ID"   
utitype="UTI Type" utieventdt="UTI DoE" casedet="Case Determination" misclassreason="Misclassification Reason(s)";
format resultstatus resultstat.;
if resultstatus=9 then output cautineedsreview;
else output cauti4;
run;

*2x2 tables;
proc sort data=cauti4; by descending Facility descending Validator; run;
proc freq data=cauti4 order=data;
by orgid_cauti; 
table facility*validator/nocol missing nocum norow nopercent out=cauti_freqsb;
format facility Validator yesno.;
run;
data cauti_freqs;length fac $5.;
set cauti_freqsb;
fac=put(facility, yesno.);
run;

*Calculating percent agreement;
proc sql; create table cauti_peragreement as select orgid_cauti,
sum((case when facility=1 and validator=1 then count else 0 end) + 
		(case when facility=0 and validator=0 then count else 0 end)) as numerator,
sum(count) as denom, put(round(calculated numerator/(calculated denom)*100,.1),4.1) as PerAgree
from cauti_freqs 
group by orgid_cauti;
quit;

data _null_;
set cauti_peragreement;
call symput ('cautipa', peragree);
call scan("&path", -1, pos, length,"\");
call symput("reppath", substr("&path",1,pos-2) || "\CAUTI - &facname Validation Summary Report %sysfunc(date(),mmddyyd10.).xlsx");
run; 
%put &cautipa; 
%put &reppath;

proc sort data=cauti_freqs; by descending Validator descending fac; run;
proc sort data=cauti4; by patientid_cauti; run;

*Creating report;
ods excel file = "&reppath" 
options(sheet_interval='none' embedded_titles='yes' 
sheet_name = "2x2 Table"); options missing=0;
title1 color=black "&facname CAUTI Event Validation Summary";
title2;
proc report data=cauti_freqs nowd 
style(column)=[just=left frame=box bordercolor=black ] 
style(header)=[background=lightblue color=black fontsize=9pt bordercolor=black] 
style(lines)=[just=left fontsize=7pt color=black tagattr="wrap:no" bordercolor=white];
title1 c=black h=11pt j=center "&facname CAUTI Event Validation";
column ("Facility" fac) ("Validator" (validator, count ("Total" (count=all))));
define fac / group "" order=data;
define validator /group across order=data "" format=yesno.;
define count / missing "" ;
define all / missing "" ;
RBREAK AFTER /summarize style=[color=black];
	compute after;
	fac="Total";
	line "Percent Agreement = %SYSFUNC(strip(&cautipa))%"; endcomp;
compute before _page_ /style=[background=white color=black tagattr="wrap:no" fontsize=10pt bordercolor=white bordertopcolor=white just=left];
	line "Table 1. CAUTI Event Validation Agreement"; endcomp;
run;
title1;
*Linelist;
ods excel options(sheet_name = "CAUTI Linelist" sheet_interval="now" 
flow="header, data"); options missing="";
proc report data=cauti4 nowd
style(column)=[just=left frame=box verticalalign=top]
style(header)=[background=lightblue font_size=8pt color=black  bordercolor=black cellspacing=1];
label; column patientid_cauti utieventdt utitype outcome casedet misclassreason; 
run;
ods excel close;
options missing=.;
%end;

/*HYST*/
%else %if &HAI=HYST %then %do;
proc import datafile="&path" 
out=hyst (where=(orgid_hyst_2023 =&orgid))
dbms=csv replace;
guessingrows=1000;
run;

proc format;
value casedet
1="Correctly Reported/Correctly Not Reported"
2="Over-reported HAI"
3="Under-reported HAI";

value oc_hyst
1="A) Not a candidate HYST: Did not meet NHSN Operative Procedure definition"
2="B) SSI present"
3="C) No SSI";

value ssidepth
1="Superficial Incisional"
2="Deep Incisional"
3="Organ/Space (specify site)";

value orgspace 
1 = "OREP - Deep pelvic tissue or other infection of the male or female reproductive tract"
2 = "IAB - Intraabdominal infection"
3 = "VCUF - Vaginal cuff infection";

value mc_hyst
1 = "ICD-10-PCS and/or CPT code(s) not a valid NHSN operative procedure code for surveillance"
2 = "Date of event outside the SSI surveillance period"
3 = "SSI should have been attributed to another invasive concurrent NHSN Operative Procedure"
4 = "Not an SSI due to invasive manipulation of the HYST operative procedure site after the HYST procedure"
5 = "Reported organ/space infection did not meet at least one criterion for a specific organ/space infection site listed in PSC Manual Chapter 17"
6 = "SSI reported at incorrect tissue level (specify)"
7 = "O/S SSI reported at incorrect specific organ/space infection site (specify)"
8 = "PATOS incorrectly applied"
9 = "Other (specify)";

value addmc_hyst
1="Missed case finding"
2="Clinical over-rule"
3="Used outdated criteria"
4="Diagnostic test results not in chart"
5="Other (specify)";

value atthystproc
1="HYST SSI"
2="SSI not attributable to HYST; SSI attributable to (specify)"
3="Not an SSI; invasive manipulation occurred (specify)";

value resultstat
1="True Positive"
2="False Negative"
3="False Positive"
4="True Negative" 
9="Review";

value yesno
1="Yes"
0="No";
run;

data outcome_hyst;
set hyst;
keep record_id orgid_hyst_2023 patientid_hyst_2023 proc: subinvprocinsurvpd_hyst_2023 inv: 
auditoutcome_hyst_2023 ssidepthdef_hyst_2023 ssieventdt_hyst_2023 orgspacespecify_hyst_2023 
evinfectionseendoc_hyst_2023 attribtoproc_hyst_2023 notattribhystspecify_hyst_2023 
notssispecify_hyst_2023 caseclass_hyst_2023 ccadditionalreasons_hyst_2023 ccaddreasonspec_hyst_2023 
ccmisapplied_hyst_2023 cc:;
run;

proc sort data=outcome_hyst; by orgid_hyst_2023 record_id patientid_hyst_2023; run;

data hyst2;
set outcome_hyst; 
length attribtoproc ssidepthdef $250. misclassreason $500. _outcome $250. misclassaddlreason 
indexprocs $70.;

if procsdurindex_hyst_2023___aaa = 1 then indexproc1 = "AAA"; else indexproc1="";
if procsdurindex_hyst_2023___appy = 1 then indexproc2 = "APPY"; else indexproc2="";
if procsdurindex_hyst_2023___bili = 1 then indexproc3 = "BILI"; else indexproc3="";
if procsdurindex_hyst_2023___csec = 1 then indexproc4 = "CSEC"; else indexproc4="";
if procsdurindex_hyst_2023___colo = 1 then indexproc5 = "COLO"; else indexproc5="";
if procsdurindex_hyst_2023___chol = 1 then indexproc6 = "CHOL"; else indexproc6="";
if procsdurindex_hyst_2023___gast = 1 then indexproc7 = "GAST"; else indexproc7="";
if procsdurindex_hyst_2023___her = 1 then indexproc8 = "HER"; else indexproc8="";
if procsdurindex_hyst_2023___neph = 1 then indexproc9 = "NEPH"; else indexproc9="";
if procsdurindex_hyst_2023___ktp = 1 then indexproc10 = "KTP"; else indexproc10="";
if procsdurindex_hyst_2023___xlap = 1 then indexproc11 = "XLAP"; else indexproc11="";
if procsdurindex_hyst_2023___ltp = 1 then indexproc12 = "LTP"; else indexproc12="";
if procsdurindex_hyst_2023___ovry = 1 then indexproc13 = "OVRY"; else indexproc13="";
if procsdurindex_hyst_2023___rec = 1 then indexproc14 = "REC"; else indexproc14="";
if procsdurindex_hyst_2023___sb = 1 then indexproc15 = "SB"; else indexproc15="";
if procsdurindex_hyst_2023___sple = 1 then indexproc16 = "SPLE"; else indexproc16="";
if procsdurindex_hyst_2023___vhys = 1 then indexproc17 = "VHYS"; else indexproc17="";

indexprocs=catx(", ", of indexproc1 -- indexproc17);

if ssidepthdef_hyst_2023 ne . and orgspacespecify_hyst_2023 ne . then do;
ssidepthdef=catx(": ", put(ssidepthdef_hyst_2023, ssidepth.), put(orgspacespecify_hyst_2023, orgspace.));
end; else ssidepthdef = "";

if attribtoproc_hyst_2023 ne . then do;
attribtoproc=catx(": ", put(attribtoproc_hyst_2023, atthystproc.), notattribhystspecify_hyst_2023, notssispecify_hyst_2023);
end; else attribtoproc = "";

_outcome=put(auditoutcome_hyst_2023, oc_hyst.);

if ccmisapplied_hyst_2023 ne . then do;
misclassreason=catx(": ", put(ccmisapplied_hyst_2023, mc_hyst.), ccmisappliedspec_hyst_2023, 
	ccmisappssilevelspec_hyst_2023, ccmisapporgspspec_hyst_2023);
end; else misclassreason="";

if ccadditionalreasons_hyst_2023 ne . then do;
misclassaddlreason=catx(": ", put(ccadditionalreasons_hyst_2023, addmc_hyst.), ccaddreasonspec_hyst_2023);
end; else misclassaddlreason="";

rename orgid_hyst_2023=orgid_hyst patientid_hyst_2023=patientid_hyst 
procstartdt_hyst_2023=proc1startdt procfinishdt_hyst_2023=proc1finishdt 
proc2startdt_hyst_2023=proc2startdt proc2finishdt_hyst_2023=proc2finishdt 
invproc1dt_hyst_2023=invproc1dt invproc2dt_hyst_2023=invproc2dt 
subinvprocinsurvpd_hyst_2023=subinvprocinsurvpd invproc1_hyst_2023=invproc1 
invproc2_hyst_2023=invproc2 invinfectionev_hyst_2023=evinfinvproc auditoutcome_hyst_2023=outcome 
ssieventdt_hyst_2023=ssieventdt evinfectionseendoc_hyst_2023=evinfectseendoc
caseclass_hyst_2023=casedet;
run;

data hyst4 hystneedsreview;
set hyst2;

*Creating tp/fp/tn/fn;
if casedet = 1 and outcome=2 then do;
	Validator=1; Facility=1; Resultstatus=1; end; *TP;
if casedet = 1 and outcome in (1 3) then do;
	Validator=0; Facility=0; Resultstatus=4; end; *TN;
if casedet = 3 and outcome=2 then do;
	Validator=1; Facility=0; Resultstatus=2; end; *FN;
if  casedet = 2 and outcome in (1 3) then do;
	Validator=0; Facility=1; Resultstatus=3; end; *FP;
if casedet = 2 and outcome=2 then Resultstatus=9; *review;
if casedet = 3 and outcome in (1 3) then Resultstatus=9; *review;

label orgid_hyst="OrgID" patientid_hyst="Patient ID" casedet="Case Determination" 
misclassreason="Misclassification Reason(s)" misclassaddlreason="Additional Misclassification Reasons"
ssieventdt="SSI Event Date" ssidepthdef="SSI Depth" evinfectseendoc="Evidence of Infection Seen"
attribtoproc="Attrib of SSI to HYST Proc" _outcome="Outcome";
format casedet casedet. resultstatus resultstat. subinvprocinsurvpd evinfectseendoc yesno. 
ssieventdt mmddyy10.;

if resultstatus=9 then output hystneedsreview;
else output hyst4;
run;

*2x2 tables;
proc sort data=hyst4; by orgid_hyst descending Facility descending Validator; run;
proc freq data=hyst4 order=data;
by orgid_hyst; 
table facility*validator/nocol nocum norow nopercent out=hyst_freqsb;
format facility Validator yesno.;
run;
data hyst_freqs;length fac $5.;
set hyst_freqsb;
fac=put(facility, yesno.);
run;

*Percent agreement;
proc sql; create table hyst_peragreement as select orgid_hyst,
sum((case when facility=1 and validator=1 then count else 0 end) + 
		(case when facility=0 and validator=0 then count else 0 end)) as numerator,
sum(count) as denom, put(round(calculated numerator/(calculated denom)*100,.1),4.1) as PerAgree
from hyst_freqs 
group by orgid_hyst;
quit;

data _null_;
set hyst_peragreement;
call symput ('hystpa', peragree);
call scan("&path", -1, pos, length,"\");
call symput("reppath", substr("&path",1,pos-2) || "\HYST - &facname Validation Summary Report %sysfunc(date(),mmddyyd10.).xlsx");
run; 
%put &hystpa; 
%put &reppath;

proc sort data=hyst_freqs; by descending Validator descending fac; run;
proc sort data=hyst4; by patientid_hyst ; run;

*Creating report;
ods excel file = "&reppath" 
options(sheet_interval='none' embedded_titles='yes'
sheet_name = "2x2 Table"); options missing=0;
title1 color=black "&facname HYST Event Validation Summary";
title2;
proc report data=hyst_freqs nowd 
style(column)=[just=left frame=box bordercolor=black ] 
style(header)=[background=lightblue color=black fontsize=9pt bordercolor=black] 
style(lines)=[just=left fontsize=7pt color=black tagattr="wrap:no" bordercolor=white];
title1 c=black h=11pt j=center "&facname HYST Event Validation";
column ("Facility" fac) ("Validator" (validator, count ("Total" (count=all))));
define fac / group "" order=data;
define validator /group across order=data "" format=yesno.;
define count / missing "" ;
define all / missing "" ;
RBREAK AFTER /summarize style=[color=black];
	compute after;
	fac="Total";
	line "Percent Agreement = %SYSFUNC(strip(&hystpa))%"; endcomp;
compute before _page_ /style=[background=white color=black tagattr="wrap:no" fontsize=10pt bordercolor=white bordertopcolor=white just=left];
	line "Table 1. HYST Event Validation Agreement"; endcomp;
run;
title1;

ods excel options(sheet_name = "HYST Linelist" sheet_interval="now" flow="header,data" 
absolute_column_width="20, 20, 35, 50, 20, 15, 35, 15, 50"); 
options missing="";
proc report data=hyst4 nowd
style(column)=[just=left frame=box verticalalign=top]
style(header)=[background=lightblue color=black  bordercolor=black cellspacing=1];
label; column patientid_hyst _outcome casedet misclassreason misclassaddlreason ssieventdt ssidepthdef evinfectseendoc attribtoproc; 
run;
ods excel close;
options missing=.;
%end;

/*COLO*/
%else %if &HAI=COLO %then %do;
proc import datafile="&path" 
out=colo (where=(orgid_colo_2023 =&orgid))
dbms=csv replace;
guessingrows=1000;
run;

proc format;
value casedet
1="Correctly Reported/Correctly Not Reported"
2="Over-reported HAI"
3="Under-reported HAI";

value oc_colo
1="A) Not a candidate COLO: Did not meet NHSN Operative Procedure definition"
2="B) SSI present"
3="C) No SSI";

value ssidepth
1="Superficial Incisional"
2="Deep Incisional"
3="Organ/Space (specify site)";

value orgspace 
1 = "OREP - Deep pelvic tissue or other infection of the male or female reproductive tract"
2 = "IAB - Intraabdominal infection"
3 = "VCUF - Vaginal cuff infection"
4 = "GIT - Gastrointestinal tract infection"
5 = "USI - Urinary System Infection";*hyst=123, colo=12,45;

value mc_colo
1 = "ICD-10-PCS and/or CPT code(s) not a valid NHSN operative procedure code for surveillance"
2 = "Date of event outside the SSI surveillance period"
3 = "SSI should have been attributed to another invasive concurrent NHSN Operative Procedure"
4 = "Not an SSI due to invasive manipulation of the COLO operative procedure site after the COLO procedure"
5 = "Reported organ/space infection did not meet at least one criterion for a specific organ/space infection site listed in PSC Manual Chapter 17"
6 = "SSI reported at incorrect tissue level (specify)"
7 = "O/S SSI reported at incorrect specific organ/space infection site (specify)"
8 = "PATOS incorrectly applied"
9 = "Other (specify)";

value addmc_colo
1="Missed case finding"
2="Clinical over-rule"
3="Used outdated criteria"
4="Diagnostic test results not in chart"
5="Other (specify)";

value attcoloproc
1="COLO SSI"
2="SSI not attributable to COLO; SSI attributable to (specify)"
3="Not an SSI; invasive manipulation occurred (specify)";

value resultstat
1="True Positive"
2="False Negative"
3="False Positive"
4="True Negative" 
9="Review";

value yesno
1="Yes"
0="No";
run;

data outcome_colo;
set colo;
keep attribtoproc_colo_2023 auditoutcome_colo_2023 caseclass_colo_2023 cc: ethnicity_colo_2023 
evinfectionseendoc_colo_2023 gender_colo_2023 invinfectionev_colo_2023 invproc1_colo_2023 
invproc1dt_colo_2023 invproc2_colo_2023 invproc2dt_colo_2023 notattribcolospecify_colo_2023 
notssispecify_colo_2023 orgid_colo_2023 orgspacespecify_colo_2023 patientdob_colo_2023 
patientid_colo_2023 proc: race: record_id sex_colo_2023 ssidepthdef_colo_2023 ssieventdt_colo_2023 
ssisurvpd_colo_2023 subinvprocinsurvpd_colo_2023;
run;

proc sort data=outcome_colo; by orgid_colo_2023 record_id patientid_colo_2023; run;

data colo2;
set outcome_colo;
length attribtoproc ssidepthdef $250. misclassreason $500. _outcome $250. misclassaddlreason 
indexprocs $70.;

if procsdurindex_colo_2023___aaa = 1 then indexproc1 = "AAA"; else indexproc1="";
if procsdurindex_colo_2023___appy = 1 then indexproc2 = "APPY"; else indexproc2="";
if procsdurindex_colo_2023___bili = 1 then indexproc3 = "BILI"; else indexproc3="";
if procsdurindex_colo_2023___csec = 1 then indexproc4 = "CSEC"; else indexproc4="";
if procsdurindex_colo_2023___chol = 1 then indexproc6 = "CHOL"; else indexproc6="";
if procsdurindex_colo_2023___gast = 1 then indexproc7 = "GAST"; else indexproc7="";
if procsdurindex_colo_2023___her = 1 then indexproc8 = "HER"; else indexproc8="";
if procsdurindex_colo_2023___hyst = 1 then indexproc5 = "HYST"; else indexproc5="";
if procsdurindex_colo_2023___neph = 1 then indexproc9 = "NEPH"; else indexproc9="";
if procsdurindex_colo_2023___ktp = 1 then indexproc10 = "KTP"; else indexproc10="";
if procsdurindex_colo_2023___xlap = 1 then indexproc11 = "XLAP"; else indexproc11="";
if procsdurindex_colo_2023___ltp = 1 then indexproc12 = "LTP"; else indexproc12="";
if procsdurindex_colo_2023___ovry = 1 then indexproc13 = "OVRY"; else indexproc13="";
if procsdurindex_colo_2023___rec = 1 then indexproc14 = "REC"; else indexproc14="";
if procsdurindex_colo_2023___sb = 1 then indexproc15 = "SB"; else indexproc15="";
if procsdurindex_colo_2023___sple = 1 then indexproc16 = "SPLE"; else indexproc16="";
if procsdurindex_colo_2023___vhys = 1 then indexproc17 = "VHYS"; else indexproc17="";

indexprocs=catx(", ", of indexproc1 -- indexproc17);

if ssidepthdef_colo_2023 ne . and orgspacespecify_colo_2023 ne . then do;
ssidepthdef=catx(": ", put(ssidepthdef_colo_2023, ssidepth.), put(orgspacespecify_colo_2023, orgspace.));
end; else ssidepthdef = "";

if attribtoproc_colo_2023 ne . then do;
attribtoproc=catx(": ", put(attribtoproc_colo_2023, attcoloproc.), notattribcolospecify_colo_2023, notssispecify_colo_2023);
end; else attribtoproc = "";

_outcome=put(auditoutcome_colo_2023, oc_colo.);

if ccmisapplied_colo_2023 ne . then do;
misclassreason=catx(": ", put(ccmisapplied_colo_2023, mc_colo.), ccmisappliedspec_colo_2023, 
	ccmisappssilevelspec_colo_2023, ccmisapporgspspec_colo_2023);
end; else misclassreason="";

if ccadditionalreasons_colo_2023 ne . then do;
misclassaddlreason=catx(": ", put(ccadditionalreasons_colo_2023, addmc_colo.), ccaddreasonspec_colo_2023);
end; else misclassaddlreason="";

rename orgid_colo_2023=orgid_colo patientid_colo_2023=patientid_colo 
procstartdt_colo_2023=proc1startdt procfinishdt_colo_2023=proc1finishdt 
proc2startdt_colo_2023=proc2startdt proc2finishdt_colo_2023=proc2finishdt 
invproc1dt_colo_2023=invproc1dt invproc2dt_colo_2023=invproc2dt 
subinvprocinsurvpd_colo_2023=subinvprocinsurvpd invproc1_colo_2023=invproc1 
invproc2_colo_2023=invproc2 invinfectionev_colo_2023=evinfinvproc auditoutcome_colo_2023=outcome 
ssieventdt_colo_2023=ssieventdt evinfectionseendoc_colo_2023=evinfectseendoc caseclass_colo_2023=casedet;
run;

data colo4 coloneedsreview;
set colo2;

*Creating tp/fp/tn/fn;
if casedet = 1 and outcome=2 then do;
	Validator=1; Facility=1; Resultstatus=1; end; *TP;
if casedet = 1 and outcome in (1 3) then do;
	Validator=0; Facility=0; Resultstatus=4; end; *TN;
if casedet = 3 and outcome=2 then do;
	Validator=1; Facility=0; Resultstatus=2; end; *FN;
if  casedet = 2 and outcome in (1 3) then do;
	Validator=0; Facility=1; Resultstatus=3; end; *FP;
if casedet = 2 and outcome=2 then Resultstatus=9; *review;
if casedet = 3 and outcome in (1 3) then Resultstatus=9; *review;

label orgid_colo="OrgID" patientid_colo="Patient ID" casedet="Case Determination" 
misclassreason="Misclassification Reason(s)" misclassaddlreason="Additional Misclassification Reasons"
ssieventdt="SSI Event Date" ssidepthdef="SSI Depth" evinfectseendoc="Evidence of Infection Seen"
attribtoproc="Attrib of SSI to colo Proc" _outcome="Outcome";
format casedet casedet. resultstatus resultstat. subinvprocinsurvpd evinfectseendoc yesno. 
ssieventdt mmddyy10.;

if resultstatus=9 then output coloneedsreview;
else output colo4;
run;

*2x2 tables;
proc sort data=colo4; by orgid_colo descending Facility descending Validator; run;
proc freq data=colo4 order=data;
by orgid_colo; 
table facility*validator/nocol nocum norow nopercent out=colo_freqsb;
format facility Validator yesno.;
run;
data colo_freqs;length fac $5.;
set colo_freqsb;
fac=put(facility, yesno.);
run;

*Percent agreement;
proc sql; create table colo_peragreement as select orgid_colo,
sum((case when facility=1 and validator=1 then count else 0 end) + 
		(case when facility=0 and validator=0 then count else 0 end)) as numerator,
sum(count) as denom, put(round(calculated numerator/(calculated denom)*100,.1),4.1) as PerAgree
from colo_freqs 
group by orgid_colo;
quit;

data _null_;
set colo_peragreement;
call symput ('colopa', peragree);
call scan("&path", -1, pos, length,"\");
call symput("reppath", substr("&path",1,pos-2) || "\COLO - &facname Validation Summary Report %sysfunc(date(),mmddyyd10.).xlsx");
run; 
%put &colopa; 
%put &reppath;

proc sort data=colo_freqs; by descending Validator descending fac; run;
proc sort data=colo4; by patientid_colo ; run;

*Creating report;
ods excel file = "&reppath" 
options(sheet_interval='none' embedded_titles='yes'
sheet_name = "2x2 Table"); options missing=0;
title1 color=black "&facname COLO Event Validation Summary";
title2;
proc report data=colo_freqs nowd 
style(column)=[just=left frame=box bordercolor=black ] 
style(header)=[background=lightblue color=black fontsize=9pt bordercolor=black] 
style(lines)=[just=left fontsize=7pt color=black tagattr="wrap:no" bordercolor=white];
title1 c=black h=11pt j=center "&facname COLO Event Validation";
column ("Facility" fac) ("Validator" (validator, count ("Total" (count=all))));
define fac / group "" order=data;
define validator /group across order=data "" format=yesno.;
define count / missing "" ;
define all / missing "" ;
RBREAK AFTER /summarize style=[color=black];
	compute after;
	fac="Total";
	line "Percent Agreement = %SYSFUNC(strip(&colopa))%"; endcomp;
compute before _page_ /style=[background=white color=black tagattr="wrap:no" fontsize=10pt bordercolor=white bordertopcolor=white just=left];
	line "Table 1. COLO Event Validation Agreement"; endcomp;
run;
title1;

ods excel options(sheet_name = "COLO Linelist" sheet_interval="now" flow="header,data" 
absolute_column_width="20, 20, 35, 50, 20, 15, 35, 15, 50"); 
options missing="";
proc report data=colo4 nowd
style(column)=[just=left frame=box verticalalign=top]
style(header)=[background=lightblue color=black  bordercolor=black cellspacing=1];
label; column patientid_colo _outcome casedet misclassreason misclassaddlreason ssieventdt ssidepthdef evinfectseendoc attribtoproc; 
run;
ods excel close;
options missing=.;
%end;

/*CDI*/
%else %if &HAI=CDI %then %do;
proc import datafile="&path" 
out=cdi (where=(orgid_cdi_2023 =&orgid))
dbms=csv replace;
guessingrows=1000;
run;

proc format;
value casedet
1="Correctly Reported/Correctly Not Reported"
2="Over-reported HAI"
3="Under-reported HAI";

value mc_cdi
1 = "Lab ID definition misapplication"
2 = "Duplicate reporting (<=14 days since the last CDI positive specimen in same location)"
3 = "Missed case finding/failure to review positive culture"
4 = "Did not review previous inpatient episode"
5 = "Used outdated criteria"
6 = "Other, specify";

value resultstat
1="True Positive"
2="False Negative"
3="False Positive"
4="True Negative" 
9="Review";

value yesno
1="Yes"
0="No"
9="n/a";
run;

data outcome_cdi;
set cdi ;
keep record_id orgid_cdi_2023 patientid_cdi_2023 patientdob_cdi_2023 gender_cdi_2023 sex_cdi_2023 
ethnicity_cdi_2023 race: pcsspecdt_cdi_2023 c1_: numspec:;
run;

proc sort data=outcome_cdi; by orgid_cdi_2023 record_id patientid_cdi_2023; run;

data cdi2;
set outcome_cdi;
length misclassreason $500. _outcome $250. ;

if c1_outcome_cdi_2023 ne . then do;
_outcome=put(c1_outcome_cdi_2023, casedet.); end;
else _outcome="";

if c1_reportreason_cdi_2023 ne . then do;
misclassreason=catx(": ", put(c1_reportreason_cdi_2023, mc_cdi.), c1_reportreasonother_cdi_2023); end;
else misclassreason="";

rename orgid_cdi_2023=orgid_cdi patientid_cdi_2023=patientid_cdi 
pcsspecdt_cdi_2023=SpecColldt c1_speccollloc_cdi_2023=SpecLoc c1_sameloc_cdi_2023=SameLocation 
c1_dupspec_cdi_2023=DupSpecimen c1_reportnhsn_cdi_2023=ReportableNHSN c1_outcome_cdi_2023=Outcome;
run;

data cdi4 cdineedsreview;
set cdi2;

*Creating tp/fp/tn/fn;
if ReportableNHSN=1 and outcome=1 then do;
	Validator=1; Facility=1; Resultstatus=1; end; *TP;
if ReportableNHSN=0 and outcome=1 then do;
	Validator=0; Facility=0; Resultstatus=4; end; *TN;
if ReportableNHSN=1 and outcome=3 then do;
	Validator=1; Facility=0; Resultstatus=2; end; *FN;
if ReportableNHSN=0 and outcome=2 then do;
	Validator=0; Facility=1; Resultstatus=3; end; *FP;
if ReportableNHSN=1 and outcome=2 then Resultstatus=9; *review;
if ReportableNHSN=0 and outcome=3 then Resultstatus=9; *review;

if numspeccoll_cdi_2023 <=1 then do;
SameLocation=9;
DupSpecimen=9; end;

label orgid_cdi="OrgID" patientid_cdi="Patient ID" misclassreason="Misclassification Reason(s)"
SpecColldt="Specimen Date" SpecLoc="Specimen Location" DupSpecimen="Duplicate Specimen" 
SameLocation="Same Location as Prior PCS" _outcome="Validation Outcome" ReportableNHSN="Reportable to NHSN";
format resultstatus resultstat. DupSpecimen ReportableNHSN SameLocation yesno.;
if resultstatus=9 then output cdineedsreview;
else output cdi4;
run;

*2x2 tables;
proc sort data=cdi4; by orgid_cdi descending Facility descending Validator; run;
proc freq data=cdi4 order=data;
by orgid_cdi; 
table facility*validator/nocol nocum norow nopercent out=cdi_freqsb;
format facility Validator yesno.;
run;
data cdi_freqs;length fac $5.;
set cdi_freqsb;
fac=put(facility, yesno.);
run;

*Percent agreement;
proc sql; create table cdi_peragreement as select orgid_cdi,
sum((case when facility=1 and validator=1 then count else 0 end) + 
		(case when facility=0 and validator=0 then count else 0 end)) as numerator,
sum(count) as denom, put(round(calculated numerator/(calculated denom)*100,.1),4.1) as PerAgree
from cdi_freqs 
group by orgid_cdi;
quit;

data _null_;
set cdi_peragreement;
call symput ('cdipa', peragree);
call scan("&path", -1, pos, length,"\");
call symput("reppath", substr("&path",1,pos-2) || "\CDI - &facname Validation Summary Report %sysfunc(date(),mmddyyd10.).xlsx");
run; 
%put &cdipa; 
%put &reppath;

proc sort data=cdi_freqs; by descending Validator descending fac; run;
proc sort data=cdi4; by patientid_cdi ; run;

*Creating report;
ods excel file = "&reppath" 
options(sheet_interval='none' embedded_titles='yes'  
sheet_name = "2x2 Table"); options missing=0;
title1 color=black "&facname CDI LabID Event Validation Summary";
title2;
proc report data=cdi_freqs nowd 
style(column)=[just=left frame=box bordercolor=black ] 
style(header)=[background=lightblue color=black fontsize=9pt bordercolor=black] 
style(lines)=[just=left fontsize=7pt color=black tagattr="wrap:no" bordercolor=white];
title1 c=black h=11pt j=center "&facname CDI LabID Event Validation";
column ("Facility" fac) ("Validator" (validator, count ("Total" (count=all))));
define fac / group "" order=data;
define validator /group across order=data "" format=yesno.;
define count / missing "" ;
define all / missing "" ;
RBREAK AFTER /summarize style=[color=black];
	compute after;
	fac="Total";
	line "Percent Agreement = %SYSFUNC(strip(&cdipa))%"; endcomp;
compute before _page_ /style=[background=white color=black tagattr="wrap:no" fontsize=10pt bordercolor=white bordertopcolor=white just=left];
	line "Table 1. CDI LabID Event Validation Agreement"; endcomp;
run;
title1;
ods excel options(sheet_name = "CDI LabID Linelist" sheet_interval="now" 
flow="header, data" ); options missing="";
proc report data=cdi4 nowd
style(column)=[just=left frame=box verticalalign=top]
style(header)=[background=lightblue font_size=8pt color=black  bordercolor=black cellspacing=1];
label; column patientid_cdi SpecColldt SpecLoc _outcome misclassreason DupSpecimen SameLocation ReportableNHSN; 
run;
ods excel close;
options missing=.;
%end;

/*MRSA*/
%else %if &HAI=MRSA %then %do;
proc import datafile="&path" 
out=mrsa (where=(orgid_mrsa_2023 =&orgid))
dbms=csv replace;
guessingrows=1000;
run;

proc format;
value casedet
1="Correctly Reported/Correctly Not Reported"
2="Over-reported HAI"
3="Under-reported HAI";

value mc_mrsa
1 = "Lab ID definition misapplication"
2 = "Duplicate reporting (<=14 days since the last MRSA positive specimen in same location)"
3 = "Missed case finding/failure to review positive culture"
4 = "Did not review previous inpatient episode"
5 = "Used outdated criteria"
6 = "Other, specify";

value resultstat
1="True Positive"
2="False Negative"
3="False Positive"
4="True Negative" 
9="Review";

value yesno
1="Yes"
0="No"
9='n/a';
run;

data outcome_mrsa;
set mrsa;
keep record_id orgid_mrsa_2023 patientid_mrsa_2023 patientdob_mrsa_2023 gender_mrsa_2023 
sex_mrsa_2023 ethnicity_mrsa_2023 race: pbsspecdt_mrsa_2023 s1_: numsp:;
run;

proc sort data=outcome_mrsa; by orgid_mrsa_2023 record_id patientid_mrsa_2023; run;

data mrsa2;
set outcome_mrsa;
length misclassreason $500. _outcome $250. ;

if s1_outcome_mrsa_2023 ne . then do;
_outcome=put(s1_outcome_mrsa_2023, casedet.); end;
else _outcome = "";

if s1_reportreason_mrsa_2023 ne . then do;
misclassreason=catx(": ", put(s1_reportreason_mrsa_2023, mc_mrsa.), s1_reportreasonother_mrsa_2023); end;
else misclassreason="";

rename orgid_mrsa_2023=orgid_mrsa patientid_mrsa_2023=patientid_mrsa 
pbsspecdt_mrsa_2023=SpecColldt s1_speccollloc_mrsa_2023=SpecLoc s1_sameloc_mrsa_2023=SameLocation 
s1_dupspec_mrsa_2023=DupSpecimen s1_reportnhsn_mrsa_2023=ReportableNHSN s1_outcome_mrsa_2023=Outcome;
run;

data mrsa4 mrsaneedsreview;
set mrsa2;

*Creating tp/fp/tn/fn;
if reportableNHSN=1 and outcome=1 then do;
	Validator=1; Facility=1; Resultstatus=1; end; *TP;
if reportableNHSN=0 and outcome=1 then do;
	Validator=0; Facility=0; Resultstatus=4; end; *TN;
if reportableNHSN=1 and outcome=3 then do;
	Validator=1; Facility=0; Resultstatus=2; end; *FN;
if reportableNHSN=0 and outcome=2 then do;
	Validator=0; Facility=1; Resultstatus=3; end; *FP;
if reportableNHSN=1 and outcome=2 then Resultstatus=9; *review;
if reportableNHSN=0 and outcome=3 then Resultstatus=9; *review;

if numspeccoll_mrsa_2023 <=1 then do;
SameLocation=9;
DupSpecimen=9; end;

label orgid_mrsa="OrgID" patientid_mrsa="Patient ID" misclassreason="Misclassification Reason(s)"
SpecColldt="Specimen Date" SpecLoc="Specimen Location" DupSpecimen="Duplicate Specimen" 
SameLocation="Same Location as Prior PCS" _outcome="Validation Outcome" ReportableNHSN="Reportable to NHSN";
format resultstatus resultstat. DupSpecimen ReportableNHSN SameLocation yesno.;
if resultstatus=9 then output mrsaneedsreview;
else output mrsa4;
run;

*2x2 tables;
proc sort data=mrsa4; by orgid_mrsa descending Facility descending Validator; run;
proc freq data=mrsa4 order=data;
by orgid_mrsa; 
table facility*validator/nocol nocum norow nopercent out=mrsa_freqsb;
format facility Validator yesno.;
run;
data mrsa_freqs;length fac $5.;
set mrsa_freqsb;
fac=put(facility, yesno.);
run;

*Percent agreement;
proc sql; create table mrsa_peragreement as select orgid_mrsa,
sum((case when facility=1 and validator=1 then count else 0 end) + 
		(case when facility=0 and validator=0 then count else 0 end)) as numerator,
sum(count) as denom, put(round(calculated numerator/(calculated denom)*100,.1),4.1) as PerAgree
from mrsa_freqs 
group by orgid_mrsa;
quit;

data _null_;
set mrsa_peragreement;
call symput ('mrsapa', peragree);
call scan("&path", -1, pos, length,"\");
call symput("reppath", substr("&path",1,pos-2) || "\MRSA LabID - &facname Validation Summary Report %sysfunc(date(),mmddyyd10.).xlsx");
run; 
%put &mrsapa; 
%put &reppath;

proc sort data=mrsa_freqs; by descending Validator descending fac; run;
proc sort data=mrsa4; by patientid_mrsa; run;

*Creating report;
ods excel file = "&reppath" 
options(sheet_interval='none' embedded_titles='yes'  
sheet_name = "2x2 Table"); options missing=0;
title1 color=black "&facname MRSA LabID Event Validation Summary";
title2;
proc report data=mrsa_freqs nowd 
style(column)=[just=left frame=box bordercolor=black ] 
style(header)=[background=lightblue color=black fontsize=9pt bordercolor=black] 
style(lines)=[just=left fontsize=7pt color=black tagattr="wrap:no" bordercolor=white];
title1 c=black h=11pt j=center "&facname MRSA LabID Event Validation";
column ("Facility" fac) ("Validator" (validator, count ("Total" (count=all))));
define fac / group "" order=data;
define validator /group across order=data "" format=yesno.;
define count / missing "" ;
define all / missing "" ;
RBREAK AFTER /summarize style=[color=black];
	compute after;
	fac="Total";
	line "Percent Agreement = %SYSFUNC(strip(&mrsapa))%"; endcomp;
compute before _page_ /style=[background=white color=black tagattr="wrap:no" fontsize=10pt bordercolor=white bordertopcolor=white just=left];
	line "Table 1. MRSA LabID Event Validation Agreement"; endcomp;
run;
title1;
ods excel options(sheet_name = "MRSA LabID Linelist" sheet_interval="now" 
flow="header, data" ); options missing="";
proc report data=mrsa4 nowd
style(column)=[just=left frame=box verticalalign=top]
style(header)=[background=lightblue font_size=8pt color=black  bordercolor=black cellspacing=1];
label; column patientid_mrsa SpecColldt SpecLoc _outcome misclassreason DupSpecimen SameLocation ReportableNHSN; 
run;
ods excel close;
options missing=.;
%end;
%mend;

%Summary;
